# Table of Contents

- [visualizing-data-with-custom-reports](<./visualizing-data-with-custom-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Visualizing Data with Custom Reports](<./Visualizing-Data-with-Custom-Reports.md>)
  - [Overview](<./Visualizing-Data-with-Custom-Reports/Overview.md>)
  - [Prerequisites](<./Visualizing-Data-with-Custom-Reports/Prerequisites.md>)
  - [Step 1: Navigate to the Project Directory](<./Visualizing-Data-with-Custom-Reports/Step-1-Navigate-to-the-Project-Directory.md>)
  - [Step 2: Create a Custom Report Module](<./Visualizing-Data-with-Custom-Reports/Step-2-Create-a-Custom-Report-Module.md>)
  - [Step 3: Import Facets into the Main Module](<./Visualizing-Data-with-Custom-Reports/Step-3-Import-Facets-into-the-Main-Module.md>)
  - [Step 4: Update HTML Content](<./Visualizing-Data-with-Custom-Reports/Step-4-Update-HTML-Content.md>)
  - [Step 5: Start the Development Server](<./Visualizing-Data-with-Custom-Reports/Step-5-Start-the-Development-Server.md>)
  - [Summary](<./Visualizing-Data-with-Custom-Reports/Summary.md>)
  - [Was this page helpful?](<./Visualizing-Data-with-Custom-Reports/Was-this-page-helpful.md>)
